@@ -5,7 +5,7 @@ import socketserver
 import traceback
 from abc import abstractmethod, ABC
 from decimal import Decimal
-from typing import Tuple, Optional, Union, Any
+from typing import Tuple, Optional, Union, Any, Dict
 
 from pandas import DataFrame
 
@@ -30,6 +30,11 @@ def state_runner(existing_state, message_processor):
 
 class PsqlHandler(ABC, socketserver.StreamRequestHandler, socketserver.ThreadingMixIn):
 
+    @property
+    @abstractmethod
+    def parameters(self) -> Dict[str, str]:
+        raise Exception("Not implemented")
+
     @property
     @abstractmethod
     def auth_handler_cls(self):
@@ -51,7 +56,7 @@ class PsqlHandler(ABC, socketserver.StreamRequestHandler, socketserver.Threading
 
     def handle(self):
 
-        print(f"First Connect")
+        logging.info(f"First Connect")
         logging.info(f"First connect")
 
         # timeout causes the socket to become non blockgin
@@ -74,7 +79,8 @@ class PsqlHandler(ABC, socketserver.StreamRequestHandler, socketserver.Threading
                 prepared_statements={},
                 key_file=None,
                 cert_file=None,
-                socket=self.connection
+                socket=self.connection,
+                parameters=self.parameters
             )
 
             self.init_ssl(context=context)
@@ -98,19 +104,32 @@ class PsqlHandler(ABC, socketserver.StreamRequestHandler, socketserver.Threading
             else:
                 ssl_obj.close()
 
-        print("End")
+        logging.info("End")
 
 
 class ThreadedTCPServer(socketserver.ThreadingMixIn, socketserver.TCPServer):
     pass
 
 
+default_parameters = {
+    'client_encoding': 'UTF8',
+    'application_name': 'psql',
+    'server_encidong': 'UTF8',
+    'TimeZone': 'UTC',
+    'DateSTyle': 'ISO',
+    'statement_timeout': '120000',
+    'default_tablespace': 'public',
+    'default_transaction_isolation': 'read committed'
+}
+
+
 def run(auth_handler_cls, query_handler_cls, extended_query_handler_cls, handler=None, host="", port=55432,
-        cert_file=None, key_file=None, socket_timeout=240):
+        cert_file=None, key_file=None, socket_timeout=240, parameters=default_parameters):
     auth_1 = auth_handler_cls
     query_1 = query_handler_cls
     query_2 = extended_query_handler_cls
     socket_timeout_1 = socket_timeout
+    parameters_1 = parameters
 
     if not handler:
         class Handler(PsqlHandler):
@@ -119,6 +138,8 @@ def run(auth_handler_cls, query_handler_cls, extended_query_handler_cls, handler
             extended_query_handler_cls = query_2
             socket_timeout = socket_timeout_1
 
+            parameters = parameters_1
+
             def init_ssl(self, context: Context):
                 context.key_file = key_file
                 context.cert_file = cert_file
@@ -128,7 +149,7 @@ def run(auth_handler_cls, query_handler_cls, extended_query_handler_cls, handler
     with ThreadedTCPServer((host, port), handler) as server:
         # Activate the server; this will keep running until you
         # interrupt the program with Ctrl-C
-        print(f"Running postgresql server on {host}:{port}")
+        logging.info(f"Running postgresql server on {host}:{port}")
         server.serve_forever()
 
 
@@ -143,11 +164,22 @@ def main():
 
     class TestQueryHandler(QueryHandler):
 
+
+
+        def handle_begin(self, session: Session, sql):
+            pass
+
+        def handle_end(self, session: Session, sql):
+            pass
+
+        def handle_set(self, session: Session, sql):
+            pass
+
         def handle(self, session: Session, sql) -> Tuple[Optional[Union[Any, Optional[DataFrame]]], Optional[Any]]:
             import pandas as pd
             import numpy as np
             from decimal import Decimal
-            print(f"Handling query {sql}")
+            logging.info(f"Handling query {sql}")
             return pd.DataFrame({'id': [1.232323, 2.1233, np.nan], 'name': [1, 2, 3],
                                  'p': [Decimal(1212323213123), Decimal(121312312321321323121321312321312323213),
                                        Decimal(123123213213213213213)]}), None
@@ -181,6 +213,9 @@ def main():
             Optional[Union[Any, Optional[DataFrame]]], Optional[Any]]:
             return data_frame, None
 
+    FORMAT = '%(levelname)s: %(asctime)-15s: %(filename)s: %(funcName)s: %(module)s: %(message)s'
+    logging.basicConfig(level=logging.INFO, format=FORMAT)
+
     run(auth_handler_cls=TestAuth, query_handler_cls=TestQueryHandler,
         extended_query_handler_cls=TestExtendedQueryHandler)
 
