@@ -23,11 +23,11 @@ class ReadingIO:
     def __init__(self, buff: io.BufferedIOBase):
         self.buff = buff
 
-    def read_bytes(self, n) -> bytes:
-        data = self.buff.read(n)
+    def read_bytes(self, n=0) -> bytes:
+        data = self.buff.read(n) if n > 0 else self.buff.read()
         if not data:
             raise NoData(n, 0, f"No data. Expected {n} bytes")
-        if len(data) != n:
+        if len(data) < n:
             raise NoData(n, len(data), f"Not enough data. Expected {n} bytes got {len(data)}")
 
         return data
