@@ -8,18 +8,13 @@ class NoData(Exception):
     """
 
     def __init__(self, expected_bytes: int, got_bytes: int, *args, **kwargs):
-        super.__init__(*args, **kwargs)
+        super(Exception, self).__init__(*args, **kwargs)
         self.expected_bytes = expected_bytes
         self.got_bytes = got_bytes
 
 
 def log_exception(e: Exception):
     try:
-        traceback.print_exc(e)
-    except:
-        pass
-
-    try:
-        logging.error(e)
+        logging.exception(e)
     except:
         pass
